#pragma once

#include "Permutations/NextPermutation.h"
#include "Permutations/PermuteCount.h"
#include <memory>
#include <vector>

#include "cpp11/R.hpp"
